Package: jqbr
Title: 'jQuery QueryBuilder' Input for 'Shiny'
Version: 1.0.4
Authors@R: 
    person("Harry", "Fisher", , "harryfisher21@gmail.com", role = c("aut", "cre"))
Description: A highly configurable 'jQuery' plugin offering a simple
    interface to create complex queries/filters in 'Shiny'. The outputted
    rules can easily be parsed into a set of 'R' and/or 'SQL' queries and
    used to filter data. Custom parsing of the rules is also supported.
    For more information about 'jQuery QueryBuilder' see
    <https://querybuilder.js.org/>.
License: MIT + file LICENSE
URL: https://github.com/hfshr/jqbr, https://hfshr.github.io/jqbr/
BugReports: https://github.com/hfshr/jqbr/issues
Imports: htmltools, jsonlite, shiny
Suggests: bslib, packer, testthat (>= 3.0.0)
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-09-09 10:15:33 UTC; root
Author: Harry Fisher [aut, cre]
Maintainer: Harry Fisher <harryfisher21@gmail.com>
Repository: CRAN
Date/Publication: 2025-09-09 12:20:07 UTC
Built: R 4.6.0; ; 2026-04-26 13:40:34 UTC; unix
