# jqbr <img src='./docs/assets/img/hex-qbr.png' align="right" height="160" />

![stability-wip](https://img.shields.io/badge/stability-work_in_progress-lightgrey.svg)
![License](https://img.shields.io/badge/license-MIT-green?style=flat-square)
[![R-CMD-check](https://github.com/hfshr/jqbr/workflows/R-CMD-check/badge.svg)](https://github.com/hfshr/jqbr/actions)

Shiny input bindings for [jQuery queryBuilder](https://querybuilder.js.org/index.html).

## Installation

```r
# install.packages("pak")
pak::pak("hfshr/jqbr")

```

## See it in action

The best way to see what this input can do is to checkout the demo Shiny app on shinyapps.io [here](https://harryfish.shinyapps.io/qbr_demo).

Or if you have installed the package, you can run `jqbr::run_jqbr_demo()` to launch the app locally.

## Credits

[jQuery QueryBuilder](https://querybuilder.js.org/) by [\@mistic100](https://github.com/mistic100)

[packer](https://github.com/JohnCoene/packer) by [\@JohnCoene](https://github.com/JohnCoene)

[queryBuilder](https://github.com/harveyl888/queryBuilder) R widget by [\@harveyl888](https://github.com/harveyl888)
